@@ -4,7 +4,7 @@ import csv
 import os
 import json
 import codecs
-import numpy
+import numpy as np
 import datetime
 from tqdm import tqdm
 import collections
@@ -125,11 +125,11 @@ def rm_symbol(text):
 
 class MyEncoder(json.JSONEncoder):
     def default(self, obj):
-        if isinstance(obj, numpy.integer):
+        if isinstance(obj, np.integer):
             return int(obj)
-        elif isinstance(obj, numpy.floating):
+        elif isinstance(obj, np.floating):
             return float(obj)
-        elif isinstance(obj, numpy.ndarray):
+        elif isinstance(obj, np.ndarray):
             return obj.tolist()
         elif isinstance(obj, bytes):
             return str(obj, encoding='utf-8')
@@ -455,8 +455,8 @@ def compute_vecsimilar_one_2_one(veca, vecb):
     :param vecb: 第二个向量
     :return: 两个向量的相似度
     """
-    veca = numpy.array(veca)
-    vecb = numpy.array(vecb)
+    veca = np.array(veca)
+    vecb = np.array(vecb)
     veca = veca / (veca ** 2).sum() ** 0.5
     vecb = vecb / (vecb ** 2).sum() ** 0.5
     sim = (veca * vecb).sum()
@@ -474,12 +474,12 @@ def compute_vecsimilar__one_2_many(veca, vecs):
     :return:maxarg, maxsim
     """
 
-    veca = numpy.array(veca)
-    vecs = numpy.array(vecs)
+    veca = np.array(veca)
+    vecs = np.array(vecs)
     veca = veca / (veca ** 2).sum() ** 0.5
     vecs = vecs / (vecs ** 2).sum(axis=1, keepdims=True) ** 0.5
 
-    sims = numpy.dot(veca, vecs.T)
+    sims = np.dot(veca, vecs.T)
     maxarg = sims.argmax()
     maxsim = max(sims)
     return maxarg, maxsim
@@ -495,13 +495,60 @@ def compute_vecsimilar__many_2_many(vecsa, vecsb):
     :param vecsb:[vec1, vec2, ...]
     :return:maxargs, maxsims
     """
-    veca = numpy.array(vecsa)
-    vecs = numpy.array(vecsb)
+    veca = np.array(vecsa)
+    vecs = np.array(vecsb)
     veca = veca / (veca ** 2).sum(axis=1, keepdims=True) ** 0.5
     vecs = vecs / (vecs ** 2).sum(axis=1, keepdims=True) ** 0.5
 
-    sims = numpy.dot(veca, vecs.T)
+    sims = np.dot(veca, vecs.T)
 
     maxargs = sims.argmax(1)
     maxsims = sims.max(1)
     return maxargs, maxsims
+
+def LCS(x, y):
+    c = np.zeros((len(x)+1, len(y)+1))
+    b = np.zeros((len(x)+1, len(y)+1))
+    for i in range(1, len(x)+1):
+        for j in range(1, len(y)+1):
+            if x[i-1] == y[j-1]:
+                c[i, j] = c[i-1, j-1]+1
+                b[i, j] = 2
+            else:
+                if c[i-1, j] >= c[i, j-1]:
+                    c[i, j] = c[i-1, j]
+                    b[i, j] = 1
+                else:
+                    c[i, j] = c[i, j-1]
+                    b[i, j] = 3
+    return c, b
+
+
+def getLCS(texta, textb):
+    """
+    获取最长公共序列
+    如：
+        x = '荣丰控股集团股份有限公司'
+        y = '荣丰（天津）医疗器械有限公司'
+    return:
+        荣丰有限公司
+    :param x:
+    :param y:
+    :return:
+    """
+    c, b = LCS(texta, textb)
+    i = len(texta)
+    j = len(textb)
+    lcs = ''
+    while i > 0 and j > 0:
+        if b[i][j] == 2:
+            lcs = texta[i-1]+lcs
+            i -= 1
+            j -= 1
+        if b[i][j] == 1:
+            i -= 1
+        if b[i][j] == 3:
+            j -= 1
+        if b[i][j] == 0:
+            break
+    return lcs
\ No newline at end of file
